### yuccnlptools

常用的nlp工具积累。

基于pytorch & transformers，用于文本分类、生成等任务的训练和线上部署。

### 安装

方法一：直接使用pip安装

```python
pip install yuccnlptools
```

方法二：国内pip有时较慢，可以指定使用清华源安装

```python
pip install yuccnlptools -i https://pypi.tuna.tsinghua.edu.cn/simple
```

### 使用示例

待添加

### 附录

github网页：https://github.com/yucc2018/yuccnlptools

pypi网页：https://pypi.org/project/yuccnlptools/
